@@ -46,6 +46,27 @@ class Client(object):
         logger.info("destroying snap7 client")
         return self.library.Cli_Destroy(byref(self.pointer))
 
+    def plc_stop(self):
+        """
+        stops a client
+        """
+        logger.info("stopping plc")
+        return self.library.Cli_PlcStop(self.pointer)
+
+    def plc_cold_start(self):
+        """
+        cold starts a client
+        """
+        logger.info("cold starting plc")
+        return self.library.Cli_PlcColdStart(self.pointer)
+
+    def plc_hot_start(self):
+        """
+        hot starts a client
+        """
+        logger.info("hot starting plc")
+        return self.library.Cli_PlcColdStart(self.pointer)
+
     @error_wrap
     def disconnect(self):
         """
@@ -67,8 +88,9 @@ class Client(object):
                                                              rack, slot))
 
         self.set_param(snap7.snap7types.RemotePort, tcpport)
-        return self.library.Cli_ConnectTo(self.pointer, c_char_p(six.b(address)),
-                                          c_int(rack), c_int(slot))
+        return self.library.Cli_ConnectTo(
+            self.pointer, c_char_p(six.b(address)),
+            c_int(rack), c_int(slot))
 
     def db_read(self, db_number, start, size):
         """This is a lean function of Cli_ReadArea() to read PLC DB.
@@ -80,8 +102,9 @@ class Client(object):
 
         type_ = snap7.snap7types.wordlen_to_ctypes[snap7.snap7types.S7WLByte]
         data = (type_ * size)()
-        result = (self.library.Cli_DBRead(self.pointer, db_number, start, size,
-                                  byref(data)))
+        result = (self.library.Cli_DBRead(
+            self.pointer, db_number, start, size,
+            byref(data)))
         check_error(result, context="client")
         return bytearray(data)
 
@@ -119,7 +142,6 @@ class Client(object):
         check_error(result, context="client")
         return bytearray(_buffer), size.value
 
-
     def upload(self, block_num):
         """
         Uploads a block body from AG
@@ -161,8 +183,9 @@ class Client(object):
         """
         logging.debug("db_get db_number: %s" % db_number)
         _buffer = buffer_type()
-        result = self.library.Cli_DBGet(self.pointer, db_number, byref(_buffer),
-                                byref(c_int(buffer_size)))
+        result = self.library.Cli_DBGet(
+            self.pointer, db_number, byref(_buffer),
+            byref(c_int(buffer_size)))
         check_error(result, context="client")
         return bytearray(_buffer)
 
@@ -183,7 +206,7 @@ class Client(object):
         result = self.library.Cli_ReadArea(self.pointer, area, dbnumber, start,
                                            size, wordlen, byref(data))
         check_error(result, context="client")
-        return data
+        return bytearray(data)
 
     @error_wrap
     def write_area(self, area, dbnumber, start, data):
@@ -205,6 +228,17 @@ class Client(object):
         return self.library.Cli_WriteArea(self.pointer, area, dbnumber, start,
                                           size, wordlen, byref(cdata))
 
+    def read_multi_vars(self, items):
+        """This function read multiple variables from the PLC.
+
+        :param items: list of S7DataItem objects
+        :returns: a tuple with the return code and a list of data items
+        """
+        result = self.library.Cli_ReadMultiVars(self.pointer, byref(items),
+                                                c_int32(len(items)))
+        check_error(result, context="client")
+        return result, items
+
     def list_blocks(self):
         """Returns the AG blocks amount divided by type.
 
@@ -223,9 +257,10 @@ class Client(object):
                       (blocktype, size))
         data = (c_int * 10)()
         count = c_int(size)
-        result = self.library.Cli_ListBlocksOfType(self.pointer, blocktype,
-                                           byref(data),
-                                           byref(count))
+        result = self.library.Cli_ListBlocksOfType(
+            self.pointer, blocktype,
+            byref(data),
+            byref(count))
 
         logging.debug("number of items found: %s" % count)
         check_error(result, context="client")
@@ -297,14 +332,16 @@ class Client(object):
 
     def ab_write(self, start, data):
         """
-        This is a lean function of Cli_WriteArea() to Write PLC process outputs.
+        This is a lean function of Cli_WriteArea() to write PLC process
+        outputs
         """
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         size = len(data)
         cdata = (type_ * size).from_buffer(data)
         logging.debug("ab write: start: %s: size: %s: " % (start, size))
-        return self.library.Cli_ABWrite(self.pointer, start, size, byref(cdata))
+        return self.library.Cli_ABWrite(
+            self.pointer, start, size, byref(cdata))
 
     def as_ab_read(self, start, size):
         """
@@ -328,7 +365,8 @@ class Client(object):
         size = len(data)
         cdata = (type_ * size).from_buffer(data)
         logging.debug("ab write: start: %s: size: %s: " % (start, size))
-        return self.library.Cli_AsABWrite(self.pointer, start, size, byref(cdata))
+        return self.library.Cli_AsABWrite(
+            self.pointer, start, size, byref(cdata))
 
     @error_wrap
     def as_compress(self, time):
@@ -399,8 +437,9 @@ class Client(object):
         cdata = (type_ * size).from_buffer(data)
         logger.debug("db_write db_number:%s start:%s size:%s data:%s" %
                      (db_number, start, size, data))
-        return self.library.Cli_AsDBWrite(self.pointer, db_number, start, size,
-                                        byref(cdata))
+        return self.library.Cli_AsDBWrite(
+            self.pointer, db_number, start, size,
+            byref(cdata))
 
     @error_wrap
     def as_download(self, data, block_num=-1):
